@@ -10,7 +10,7 @@ from collections import namedtuple
 from enum import Enum
 from typing import List
 
-version = '1.0.0'
+version = '0.2.66'
 version_info = list(map(int, version.split('.')))
 
 
@@ -58,7 +58,7 @@ class ComponentType():
     AioHttp = "AioHttp"
     Pyramid = "Pyramid"
     CustomEvent = "CustomEvent"
-    Log = "Log"
+    Log = "logging"
 
 
 class Layer(Enum):
