@@ -84,15 +84,16 @@ class FastTrackerConfiger:
             env_dict = os.environ
             for key, val in env_dict.items():
                 if key.startswith("FastTracker."):
+                    val_dict=json.loads(val)
                     if key.startswith("FastTracker.TenantCodeReader"):
                         config.tenant_code_reader.clear()
-                        config.set_tenant_code_reader(json.loads(val))
+                        config.set_tenant_code_reader(val_dict)
                     elif key.startswith("FastTracker.UserCodeReader"):
                         config.user_code_reader.clear()
-                        config.set_user_code_reader(val)
+                        config.set_user_code_reader(val_dict)
                     elif key.startswith("FastTracker.ServiceVersionReader"):
                         config.service_version_reader.clear()
-                        config.set_service_version_reader(val)
+                        config.set_service_version_reader(val_dict)
                     elif key.startswith("FastTracker.CarrierHeader."):
                         args = {functions.lower_case_name(key[26:]): val}
                         config.set_carrier_header(**args)
@@ -133,6 +134,7 @@ class FastTrackerConfiger:
                             config.set_collectLayer_function(**args)
                     else:
                         config_name = functions.lower_case_name(key[12:])
+                        functions.log("config_name:%s,key:%s,val:%s",config_name,key[12:],val)
                         setattr(config, config_name, val)
         except Exception as e:
             functions.log("python探针环境变量读取错误信息：%s", str(e))
