@@ -55,7 +55,8 @@ def _gen_fast_get_response_func(old_execute):
                     item.set_frontend_trace_id(request.headers[trace_id_name.capitalize()])
                 if trace_id_name.upper() in request.headers and type(item) is Carrier:
                     item.set_frontend_trace_id(request.headers[trace_id_name.upper()])
-            with context.new_entry_span(op=request.path, carrier=carrier) as span:
+            functions.log("fast_tornado op:%s",request.path)
+            with context.new_entry_span(op=request.path.split("?")[0], carrier=carrier) as span:
                 span.layer = Layer.Http
                 span.component = ComponentType.Tornado
                 try:
@@ -80,7 +81,8 @@ def _gen_fast_get_response_func(old_execute):
                 # tenant_code\user_code\env_code 根据配置动态获取并更新
                 set_code(config.tenant_code_reader, request, "tenant_code")
                 set_code(config.user_code_reader, request, "user_code")
-                set_code(config.env_code_reader, request, "env_code")
+                set_code(config.service_version_reader,request,"service_version")
+                # set_code(config.env_code_reader, request, "env_code")
             return result
 
     else:
@@ -100,7 +102,8 @@ def _gen_fast_get_response_func(old_execute):
                     item.set_frontend_trace_id(request.headers[trace_id_name.capitalize()])
                 if trace_id_name.upper() in request.headers and type(item) is Carrier:
                     item.set_frontend_trace_id(request.headers[trace_id_name.upper()])
-            with context.new_entry_span(op=request.path, carrier=carrier) as span:
+            functions.log("fast_tornado op:%s",request.path)
+            with context.new_entry_span(op=request.path.split("?")[0], carrier=carrier) as span:
                 span.layer = Layer.Http
                 span.component = ComponentType.Tornado
                 # v6+use this
@@ -124,7 +127,8 @@ def _gen_fast_get_response_func(old_execute):
 
                 set_code(config.tenant_code_reader, request, "tenant_code")
                 set_code(config.user_code_reader, request, "user_code")
-                set_code(config.env_code_reader, request, "env_code")
+                set_code(config.service_version_reader,request,"service_version")
+                # set_code(config.env_code_reader, request, "env_code")
 
                 functions.log("tornado span is: %r", span)
             return result
@@ -132,7 +136,7 @@ def _gen_fast_get_response_func(old_execute):
     return _fast_get_response
 
 
-def set_code(reader, request, code_type="tenant_code"):
+def set_code(readerList, request, code_type="tenant_code"):
     """
     根据配置从不同渠道（cookie\header\querystring\env）获取tenant_code、user_code、env_code等数据
     :param reader:
@@ -141,49 +145,54 @@ def set_code(reader, request, code_type="tenant_code"):
     :return:
     """
     code = ""
-    if not reader:
+    if not readerList:
         return code
 
-    reader_type = reader.get("ReaderType")
-    reader_key = reader.get("ReaderKey")
-    try:
-        if reader_type == ReaderType.Cookie:
-            # # tornado6.0.4 is ok
-            # code = request.get_cookie(reader_key, "")
-            # tornado5.1.1 is ok
-            # code: Set-Cookie: env_c=gog <Morsel: env_c=gog>
-            # request.cookies is A dictionary of Cookie.Morsel objects
-            # tornado5.1.1 source code->tornado-httputil.py-HTTPServerRequest-cookies
-            cookie = request.cookies.get(reader_key, "")
-            if type(cookie) == str:
-                code = cookie
+    for reader in readerList:
+
+        reader_type = reader.get("ReaderType")
+        reader_key = reader.get("ReaderKey")
+
+        try:
+            if reader_type == ReaderType.Cookie and request.cookies:
+                # # tornado6.0.4 is ok
+                # code = request.get_cookie(reader_key, "")
+                # tornado5.1.1 is ok
+                # code: Set-Cookie: env_c=gog <Morsel: env_c=gog>
+                # request.cookies is A dictionary of Cookie.Morsel objects
+                # tornado5.1.1 source code->tornado-httputil.py-HTTPServerRequest-cookies
+                cookie = request.cookies.get(reader_key, "")
+                if type(cookie) == str:
+                    code = cookie
+                else:
+                    code = request.cookies.get(reader_key, "").value
+                # code = request.cookies.get(reader_key, "").value
+            elif reader_type == ReaderType.RequestHeader:
+                code = request.headers[reader_key] if reader_key in request.headers else ""
+            elif reader_type == ReaderType.QueryString:
+                # data = json.loads(request.body.decode('utf-8'))
+                # # tornado6.0.4 is ok
+                # code = request.get_argument(reader_key, default="") if request.arguments.has_key(reader_key) else ""
+                # tornado5.1.1
+                arg = request.arguments.get(reader_key)
+                code = arg[0].decode("utf-8") if type(arg) == list else ""
+            elif reader_type == ReaderType.Environment:
+                import os
+
+                code = os.getenv(reader.get("ReaderKey"), "")
             else:
-                code = request.cookies.get(reader_key, "").value
-            # code = request.cookies.get(reader_key, "").value
-        elif reader_type == ReaderType.RequestHeader:
-            code = request.headers[reader_key] if reader_key in request.headers else ""
-        elif reader_type == ReaderType.QueryString:
-            # data = json.loads(request.body.decode('utf-8'))
-            # # tornado6.0.4 is ok
-            # code = request.get_argument(reader_key, default="") if request.arguments.has_key(reader_key) else ""
-            # tornado5.1.1
-            arg = request.arguments.get(reader_key)
-            code = arg[0].decode("utf-8") if type(arg) == list else ""
-        elif reader_type == ReaderType.Environment:
-            import os
+                code = ""
 
-            code = os.getenv(reader.get("ReaderKey"), "")
-        else:
-            code = ""
-
-        # 设置用户自定义字段值
-        if code_type == "tenant_code" and not config.custom_tenant_code:
-            config.custom_tenant_code = code
-        elif code_type == "user_code" and not config.custom_user_code:
-            config.custom_user_code = code
-        elif code_type == "env_code" and not config.custom_env_code:
-            config.custom_env_code = code
-    except BaseException as e:
-        functions.log("tornado 获取code错误，错误信息: %r", str(e))
+            if code != "":
+                break
+        except BaseException as e:
+            functions.log("tornado 获取code错误，错误信息: %r", str(e))
 
+    # 设置用户自定义字段值
+    if code_type == "tenant_code" and not config.custom_tenant_code:
+        config.custom_tenant_code = code
+    elif code_type == "user_code" and not config.custom_user_code:
+        config.custom_user_code = code
+    elif code_type == "service_version" :
+        config.custom_service_version = code
     return code
